@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 use Devel::PPPort 3.42;
 use Dist::Zilla 6.0;
@@ -242,7 +242,7 @@ has _running_in_ci => (
     default => sub {
 
         # AGENT_ID is Azure Pipelines.
-        return $ENV{TRAVIS} || $ENV{AGENT_ID};
+        return $ENV{TRAVIS} || $ENV{AGENT_ID} ? 1 : 0;
     },
 );
 
@@ -860,7 +860,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
